pub enum InputItem {
Known(KnownInputItem),
Other(Value),
}Expand description
One item in the input list, mirroring ResponseInputItemParam.
Unrecognized type values deserialize into InputItem::Other and
round-trip without data loss (object key order is normalized through
serde_json::Value, but no field is dropped), so exotic item types
(computer_use, shell, apply_patch, skills, MCP, compaction, …) survive
a decode/encode cycle.
Variants
Implementations
Sourceimpl InputItem
impl InputItem
Sourcepub fn user(content: impl Into<EasyContent>) -> Self
pub fn user(content: impl Into<EasyContent>) -> Self
A user message with plain text or multimodal content.
Sourcepub fn message(role: impl Into<String>, content: impl Into<EasyContent>) -> Self
pub fn message(role: impl Into<String>, content: impl Into<EasyContent>) -> Self
A system/developer/assistant message with plain text or multimodal content.
Sourcepub fn function_call(
call_id: impl Into<String>,
name: impl Into<String>,
arguments: impl Into<String>,
) -> Self
pub fn function_call( call_id: impl Into<String>, name: impl Into<String>, arguments: impl Into<String>, ) -> Self
A function call previously made by the model (for replaying history).
Sourcepub fn function_call_output(
call_id: impl Into<String>,
output: impl Into<String>,
) -> Self
pub fn function_call_output( call_id: impl Into<String>, output: impl Into<String>, ) -> Self
The result of executing a function call, sent back to the model.
Sourcepub fn item_reference(id: impl Into<String>) -> Self
pub fn item_reference(id: impl Into<String>) -> Self
A reference to a previously created item, by id.